#
# spec file for package python-holidays
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-holidays
Version:        0.53
Release:        1.1
Summary:        Python library for generating holidays on the fly
License:        MIT
URL:            https://github.com/vacanza/python-holidays
Source:         https://github.com/vacanza/python-holidays/archive/refs/tags/v%{version}.tar.gz#/holidays-%{version}.tar.gz
BuildRequires:  %{python_module convertdate}
BuildRequires:  %{python_module hijri-converter >= 2.2}
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module korean-lunar-calendar}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module polib}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testsuite}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil
BuildArch:      noarch
%python_subpackages

%description
A Python library for generating country, province and state specific sets of holidays on the fly.
It makes determining whether a specific date is a holiday possible.

%prep
%setup -q -n python-holidays-%{version}

%build
scripts/l10n/generate_mo_files.py
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc CHANGES README.rst
%{python_sitelib}/holidays
%{python_sitelib}/holidays-%{version}.dist-info

%changelog
* Mon Jul 22 2024 Adrian Schröter <adrian@suse.de>
- update to 0.53:
  * Update Chile holidays: add bank holidays
  * Extend HolidayBase::__setitem__ to handle names including '; '
* Mon Jul 22 2024 Adrian Schröter <adrian@suse.de>
- re-apply rudi's fix for generating translations
  need to generated and installed, running at %%check produces an
  incomplete package, not able to work
* Wed Jun 19 2024 Adrian Schröter <adrian@suse.de>
- update to 0.51:
  * Update Aruba and Curaçao holidays l10n (split locales) (#1827 by @KJhellico)
  * Update Brazil holidays: add new Nov 20 holiday (#1832 by @KJhellico)
  * Update CI/CD job concurrency (#1823 by @arkid15r)
  * Update CI/CD job concurrency (#1830 by @arkid15r)
  * Update README.rst (#1828 by @arkid15r)
  * Update ruff configuration (#1819 by @arkid15r)
  * Align India subdivisions with ISO 3166-2 (#1821 by @KJhellico)
  * Migrate to codecov.io (#1818 by @arkid15r)
  * Narrow down ignored warnings (#1816 by @arkid15r)
  * Refactor some holidays with uncommon rules (#1807 by @KJhellico)
  * Add Greenland holidays (#1811 by @Klintrup, @arkid15r)
  * Fix docs: update Italy docstring (#1808 by @arkid15r)
  * Update Italy holidays (#1805 by @KJhellico)
  * Add 2024 Russian Substituted Holidays (#1799 by @PPsyrius)
  * Add Georgian government holiday for May 17, 2024 (#1802 by @PPsyrius, @arkid15r)
  * Add v1 future incompatibility warning (#1801 by @arkid15r)
  * Migrate Japan holidays to ObservedHolidayBase (#1810 by @KJhellico)
  * Synchronize entity dynamic imports (#1794 by @Izzette)
  * Add IFEU holidays (#1792 by @benjfield, @arkid15r)
  * Update Hong Kong holidays (#1767 by @KJhellico, @arkid15r)
  * Update Malaysia holidays (#1791 by @KJhellico)
  * Update observed rules: add holiday removal support (#1796 by @arkid15r)
  * Address numpy int argument conversion issue (#1782 by @arkid15r)
  * Replace `datetime::timedelta` with custom function (#1785 by @KJhellico)
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 0.48:
  * Introduce workdays calculation support
  * Refactor `HolidayBase::__getattr__`: speed up _add_holiday_*
    methods
  * Add Palau holidays
  * Update Greece holidays: move 2024 Labor Day to May 7
  * Update Timor-Leste holidays
  * Update United States holidays: fix Confederate Memorial Day
    in MS
  * Update badges in README
  * Update CI/CD: fix macOS Python versions
  * Extend HolidayBase::_add_holiday family methods with Easter
    support
  * Prioritize entity default holiday category processing
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 0.47:
  * Refactor some sequential holidays
  * Add Jordan holidays
  * Change contributors badge placement
  * Update Australia holidays: fix Sovereign's Birthday dates in
    WA
  * Update Eid al-Fitr 2024 dates
  * Update European Central Bank holidays
  * Update Poland holidays: fix Ascension Day
  * Update South Africa holidays: add public holiday on May 29,
    2024
  * Update contributing guidelines
* Tue Apr  2 2024 Dirk Müller <dmueller@suse.com>
- update to 0.46:
  * Fix Romanian language strings: replace U+015F with proper
    U+0219
  * Update (c) in file headers and LICENSE
  * Update Australia holidays
  * Update Makefile clean action
  * Update US tests: Day After Thanksgiving
  * Update United Kingdom holidays: fix observed New Year's Day
    in Scotland
  * Update tests: use assertIsInstance
  * Fix README layout (attempt 1)
  * Add file header pre-commit check
  * Add package build tests
  * Unify file headers after recent update
* Tue Mar 19 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.45:
  * Add Python 3.12 support
  * Add Kuwait holidays
  * Add Seychelles holidays
  * Fix SonarCloud security hotspots
  * Update Mexico holidays
  * Update Ethiopia holidays
  * Update Ukrainian translations (proper apostrophe)
  * Update snapshots: Portugal holidays
  * Add `UNOFFICIAL` category for the United States
  * Introduce subdivisions aliases
  * Update Ireland holidays
  * Update Portugal holidays: fix Carnival date
  * Update Taiwan holidays
  * Update Thailand holidays: add Bridge Public Holiday on Apr 12, 2024
- Add missing BuildRequires on importlib-metadata.
* Wed Feb  7 2024 Dirk Müller <dmueller@suse.com>
- update to 0.42:
  * Add Ghana holidays
  * Add Jersey holidays
  * Update Costa Rica holidays
  * Update Croatia holidays
  * Update Greece holidays
  * Update Switzerland holidays
  * Update United Arab Emirates holidays
  * 2020 China calendar discrepancies fix
  * Add United Kingdom's Whit Monday holidays for pre-1971 years
  * Unify common holidays name translation
  * Use current version for release notes generation
* Tue Jan 23 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.41:
  * Introduce observed_estimated_label
  * Update Argentina holidays
  * Update Cyprus holidays
  * Update Malaysia holidays
  * Update Paraguay holidays
  * Update Thailand holidays
  * Add Papua New Guinea holidays
  * Fix United States and Guam holidays
  * Extend native holiday categories support
  * Update NYSE holidays: fix New Year's Day observed
  * Update Netherlands holidays: fix Liberation Day
  * Add categories and subdivisions support to special observed holidays
  * Add categories and subdivisions support to substituted holidays
  * Update Israel holidays
  * Update Ukraine holidays
  * Migrate NYSE holidays to ObservedHolidayBase
  * Add special holidays per subdivisions support
  * Add special_holidays_observed support
  * Add Bahamas holidays
  * Add Timor-Leste holidays
  * Add Tonga holidays
  * Update Portugal holidays: add holiday categories
  * Add Maldives holidays
  * Add Tanzania holidays
  * Implement Tanzania `StaticHolidays`
  * Add Laos holidays
  * Update Belarus holidays: add substituted holidays
  * Update NYSE holidays: fix Juneteenth National Independence Day start year
  * Update Spain holidays
  * Add merge queue support
  * Update Belgium holidays: add bank holidays
  * Update Canada holidays
  * Update Liechtenstein holidays: specify bank holidays
  * Update United Kingdom holidays
  * Add subdivision category holidays support
  * Add Barbados holidays
  * Add Iran holidays
  * Add Vanuatu holidays
  * Update Barbados holidays
  * Update Singapore holidays: add 2023 Polling Day
  * Update Slovenia holidays: add 2023 Solidarity Day
  * Update Vanuatu holidays
  * Update South Korea holidays
  * Update Taiwan holidays
  * Update Uruguay holidays
  * Add JULIAN_REVISED_CALENDAR calendar
  * Add Guatemala holidays
  * Update United Kingdom holidays: update certain holidays start years
  * Add HolidayBase methods for relative weekdays calculation
  * Add Brunei Darussalam holidays
  * Add Burkina Faso holidays
  * Add Cambodia holidays
  * Add Chad holidays
  * Add Columbus day to InternationalHolidays
  * Allow using ISO 639-2 (three-letter) language codes
  * Make Tynwald Day movable from 1992 onwards for Isle of Man
  * Use aware UTC datetimes internally
  * Introduce Asian holidays pre-calculated data
  * Add Belize holidays
  * Add Cameroon holidays
  * Add El Salvador holidays
  * Add Gabon holidays
  * Update Azerbaijan holidays: use custom Islamic calendar
  * Update Morocco holidays
  * Update Vatican City holidays
  * Introduce entity lazy loading
  * Add Algeria holidays
  * Update coverage upload process
  * Add Ecuador holidays
  * Add polib as a deploy process dependency
  * Introduce subdivision holidays methods
  * Refactor .po and .mo files generation
  * Update Andorra parish holidays
  * Add Costa Rica holidays
  * Update Portugal holidays
  * Fix NYSE New Year's Day observance calculation
  * Update Ireland holidays: St. Bridget's Day
  * Update Mexico holidays
  * Update Saudi Arabia holidays
  * Add functions for relative weekdays calculation
  * Use the built-in library for time zone functions
- Update Source and URL.
- Switch to pyproject macros.
- Stop using greedy globs in %%files.
* Fri Mar  3 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.20:
  * Add localization support, #827 (@arkid15r, @bkthomps, @dragoon)
  * Introduce `HolidayBase::_is_leap_year()`, #886 (@arkid15r)
  * Introduce `HolidayBase::_is_monday` - `HolidayBase::_is_sunday` helper
    methods, #841 (@arkid15r)
  * Change holiday name separator from ", " to "; ", #922 (@arkid15r)
  * Fix Hong Kong, #928 (@KJhellico)
  * Fix Islamic holidays calculation, #914 (@KJhellico)
  * Fix Thailand related changes coverage decrease, #942 (@arkid15r, @PPsyrius)
  * Improve Thailand holidays, #929 (@PPsyrius, @arkid15r, @KJhellico)
  * Update Australia holidays: fix 2020 QLD holidays, #923 (@arkid15r)
  * Update Bolivia holidays, #910 (@KJhellico)
  * Update Bosnia and Herzegovina holidays, #909 (@KJhellico)
  * Update Jamaica holidays, #913 (@KJhellico)
  * Update PR template, #960 (@arkid15r)
  * Update Poland holidays, add uk localization, #947 (@KJhellico)
  * Add International Women's Day for DE-MV, #936 (@alexanderschulze)
  * Add Marshall Islands (ISO-3666-1 code MH), #937 (@mborsetti)
  * Add Northern Mariana Islands (ISO-3666-2 code US-MP), #939 (@mborsetti)
  * ISO 3166-1 for US subdivisions, #941 (@mborsetti, @dr-prodigy)
  * Add Albania initial support #895 (@arkid15r)
  * Add Andorra initial support #896 (@arkid15r)
  * Add Bahrain initial support #888 (@arkid15r)
  * Add Montenegro initial support #897 (@arkid15r)
  * Add San Marino initial support #898 (@arkid15r)
  * Add Vatican City initial support #904 (@arkid15r)
  * Add Monaco holidays #877 (@KJhellico)
  * Migrate prophet.hdays countries #887 (@arkid15r)
  * Singapore holidays update #880 (@KJhellico)
  * PyMeeus for equinox and solstice calculation #828, #863 (Nalguedo)
  * Easter holidays refactoring and unification #803 (KJhellico)
  * Observed holidays calc optimizations #824 (KJhellico)
  * Special holidays refactoring for 13 countries #796 (arkid15r, KJhellico)
  * Support for Indonesia #787 (KJhellico)
  * Support for Pakistan #847 (KJhellico)
  * Support for Armenia #875 (KJhellico)
  * Korea renamed to South Korea #797 (arkid15r)
  * Azerbaijan: refactoring #859 (KJhellico)
  * Hong Kong: optimizations #786 (KJhellico)
  * Zambia: optimizations and refactoring #798 (KJhellico)
  * Vietnam: optimizations and refactoring #799 (KJhellico)
  * Malaysia: optimizations, refactoring and fixes #802, #858 (KJhellico)
  * New Zealand: optimizations and refactoring #836 (KJhellico)
  * Chile: optimizations #834 (KJhellico) + fixes #828 (Nalguedo)
  * Uruguay updates #809 (KJhellico)
  * Kazakhstan updates #829, #867 (KJhellico)
  * Canada fixes #811 (jasonjensen)
  * Nigeria updates #823 (KJhellico)
  * NY Stock Exchange updates #817, #853 (SnowX65, KJHellico)
  * New Zealand optimizazions #872 (KJhellico)
  * Madagascar updates #818 (KJhellico)
  * Paraguay updates #819 (KJhellico)
  * United Kingdom updates #840 (KJhellico)
  * South Africa: optimizations and updates #820, #848 (KJhellico)
  * US updates #857 (KJhellico)
  * Switzerland: optimizations, fix #821 (KJhellico)
  * Angola: optimizations, fix #822, #835 (KJhellico)
  * India updates #825 (KJhellico)
  * NY Stock Exchange updates #833 (SnowX65, KJhellico)
  * Hungary fixes #826 (KJhellico)
- Switch to GitHub source so the testsuite is included.
* Tue Oct 11 2022 pgajdos@suse.com
- really  update to version 0.16
- does not require python-six
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update Version 0.16
  Released September 16, 2022
  This release is dedicated to Queen Elizabeth II (21 April 1926 – 8 September 2022),
  who lived her long life as a monarch through 2 centuries, in both happy and difficult moments,
  with grace, dignity and an always inspiring strong sense of duty and warm heart.
  Goodbye "Lilibet", you have symbolically been a queen, a mother and a grandmother
  to a lot of us, and will be dearly missed.
  - Financial market support review, new method financial_holidays(..) #694 (dr-p)
  - Support for Moldova #695 (Thedand)
  - Support for Bolivia #679, #698 (kasya)
  - UK updates #702 (JPunter, violuke)
  - Australia updates #699 (Ryan-McCrory, dr-p)
  - Canada updates #710 (bkthomps)
  - New Zealand updates #708, #709 (dr-p, markhoneth)
  - NYSE updates #693, #696 (kasya)
- Update Version 0.15
  Released August 21, 2022
  - Added support for Python3.11 (dr-p)
  - Updated README - improved badges area (dr-p)
  - Support for Cuba #678 (bthompson, dr-p)
  - Typechecking implementation, first release (HolidayBase, utils, some sample countries) #661 (dimbleby)
  - Test coverage improvement #633 (akosfurton, dr-p)
  - Drop support for UK subdivisions as countries (England, Scotland..) (dr-p)
  - Drop support for IsleOfMan as UK subdivision (dr-p)
  - Drop support for PortugalExt (ie: extended Portugal) (dr-p)
  - US fixes #675 (arkid15r)
  - Colombia fixes & test improvements #676 (bkthomps)
  - Venezuela fixes & test improvements #677 (bkthomps)
  - Canada fixes #579 (dr-p, scubaandre)
  - Ukraine refactoring #681 (kasya)
  - Italy update #689 (g-gg, dr-p)
  - Bump pre-commit and setup-python actions #672, #682, #686, #688 (dr-p)
  - Doc example fix #685 (steakhutzeee, dr-p)
- Update Version 0.14.2
  Released June 5, 2022
  - Drop support for EOL Python 3.6 #328 (hugovk, dr-p)
  - Package review #662 (dimbleby)
  - Added financial markets support: ECB and NYSE, list_supported_financial() method (dr-p)
  - Support for NY Stock Exchange #651, #458 (nadime, dr-p)
  - Support for Malta #612, #630 (rafelbev)
  - Support for Madagascar #656 (fav007)
  - Support for Cyprus #410, #665 (digidestination, avnigo)
  - Ireland as standalone country #636, #639 (TeoTN, dr-p, javicalle)
  - Australia fixes #631 (jeremychrimes)
  - Singapore updates #652 (mborsetti)
  - Saudi Arabia fixes #642 (OsaydAbdu)
  - Spain fixes #634 (javicalle)
  - US fixes #648 (dashdrum)
  - Greece fixes #659 (tudorvaran)
  - India doc fixes #657 (dr-p)
  - Poland fix #663 (kfsz)
- Update Version 0.13
  Released February 15, 2022
  - New subdivision parameter (subdiv), prov/state deprecation #608, #597, #374 (mborsetti)
  - CountryHoliday class deprecation (replaced by country_holidays) (mborsetti, dr-p)
  - Sphinx documentation #600, #601, #602 (mborsetti)
  - Integration of mypy in pre-commit #620 (mborsetti)
  - Wrong year expansion fix #586, #606, #625 (mborsetti, TeejMonster, dr-p)
  - Refactoring / cleanups / code and naming reviews (mborsetti)
  - Support for Uzbekistan #593 (slako, dr-p)
  - Italy fixes/improvements #617, #614 (energywave)
  - Spain improvements #580, #603, #624 (gtrabanco, delaosa, dr-p)
  - UAE updates (weekend change) #609 (marcomasulli, dr-p)
  - India updates #548 (mborsetti)
  - US fixes #594, #595, #619 (apicht, SudoRob, dr-p)
  - UK fixes #587 (mborsetti)
  - Russia fixes #582 (Enzokot)
  - Type hints fixes #589 (mborsetti)
- Update Version 0.12
  Released January 4, 2022
  - Copyright update 2022
  - Sphinx documentation stub (mborsetti, dr-p)
  - Support for Kazakhstan #534 (chiuczek, intelliHugh)
  - Support for Azerbaijan #540 (eldar-mustafayev)
  - Support for Tunisia #543 (ihebski)
  - Support for Taiwan #547 (ifurther)
  - Support for North Macedonia #570 (tserekh)
  - Support for Ethiopia #558 (tedtad, dr-p)
  - Travis CI removal #557 (mborsetti, dr-p)
  - CD/CI tests - Pypi versions review (dr-p)
  - More useful __repr__ and __str__ #360 (dr-p, kootenpv, d33tah)
  - Drop support for Czech (ie: misspelled Czechia) (dr-p)
  - Drop support for Polish (ie: misspelled Poland) (dr-p)
  - Drop support for Slovak (ie: misspelled Slovakia) (dr-p)
  - Test coverage improvement (dr-p)
  - "country" property moved to class attributes #573 (dr-p, madphysicist)
  - Date slices support fix #529, #530 (justinwaf, mborsetti, dr-p)
  - Dictionary changed during iteration fix #569 (mborsetti)
  - Doc fixes #549 (canute24)
  - UK standalone states deprecation #566 (dr-p)
  - Venezuela ISO code + other fixes #567, #576 (Skatox, dr-p, antusystem)
  - Canada updates and test review #533, #536 (cturra)
  - US updates and fixes #537, #559, #578 (khawley, evohnave, amelkiy, dr-p)
  - India fixes #553, #554, #539 (canute24, dr-p)
  - Spain fixes #555 (tserekh)
  - Italy fixes #546 (dr-p, rtraverso86)
  - Korea fixes #535 (0xF4D3C0D3)
  - Colombia fixes #564 (jahirfiquitiva)
- Update to Version 0.11.3.1
  Released September 29, 2021
  - Support for Zambia #495, #496 (engineervix)
  - Support for Uruguay #489, #490, #491, #492, #493 (jemazzeo, dr-p)
  - Support for Lesotho #512 (pietervdw115)
  - Support for Namibia #513 (pietervdw115)
  - Support for Swaziland #514 (pietervdw115)
  - Support for Zimbabwe #517 (pietervdw115)
  - Support for China #515 (tserekh)
  - Refactor lunisolar and islamic calendar #524 (mborsetti)
  - Removed six dependency #494 (mborsetti)
  - Type hinting #497, #498 (mborsetti)
  - Malaysia refactoring & updates #524 (mborsetti)
  - New Zealand updates #499 (36wish)
  - USA, Angola fixes (jusce17)
  - Kenya updates #502 (MainaKamau92)
  - Korea updates #508 (0xF4D3C0D3, dr-p)
  - Bulgaria updates #509 (BasakUlker, dr-p)
  - Australia updates #516 (cmckeague)
  - South Africa updates (lispwarez, dr-p)
  - Canada updates #457 (dr-p)
  - PRTE (PortugalExt) fix #520 (dr-p)
  - Norway updates #472 (dr-p)
  - Chile updates #473 (dr-p)
  - Australia updates #525 (jeremychrimes)
  - README iso codes typo / improvements #520 (dr-p)
  - .gitattributes fix #522 (mborsetti)
-Update to Version 0.11.2
  Released July 18, 2021
  - Support for Venezuela #470 (antusystem, dr-p)
  - Support for Botswana #477 (pietervdw115)
  - Support for Malaysia #466 (jusce17) *needs improvement*
  - Poland fix #464 (m-ganko)
  - Singapore updates for 2022 #456 (mborsetti)
  - US updates #474, #488 (ChristianAlexander, jusce17)
  - NG updates #486 (pietervdw115)
  - UK updates #487 (orrock, dr-p)
  - .gitignore fix #462 (TheLastProject)
  - Pre-commit v.2.0.3 (dr-p)
* Mon May  3 2021 Matej Cepl <mcepl@suse.com>
- Use %%pytest macro
* Mon May  3 2021 Adrian Schröter <adrian@suse.de>
- update to version 0.11.1
  * Support for Saudi Arabia
  * Support for Curacao
  * Support for Jamaica
  * Support for Georgia
  * init.py flake8 issue fix
  * Korea 2020 fix
  * Singapore fix for multi-year
  * Israel fix
  * Japan fix
  * Serbia fix
  * United Kingdom get_list fix
  * Singapore fix for multi-year
  * Fixed holidays pickling
- remove:
  - disable-lag-baomer.patch
  - disable-flake.patch
* Mon Feb  8 2021 Adrian Schröter <adrian@suse.de>
- update to version 0.10.5.2
  * Dropped support for Python 2 (dr-p)
  * Removed convertdate<=2.2.0 constraint (dr-p)
  * Travis CI integration review (dr-p)
  * Support for Mozambique (jusce17)
  * Angola fixes (jusce17)
  * Portugal localized holidays (jusce17)
  * Disable year expansion on name search #411 (giladmaya)
  * Israel fixes (new convertdate version) #407 (giladmaya)
  * Ireland fixes (ISO-2 code, partial split from UK) #417 (javicalle)
  * Honduras fix (ISO-2 code) #405 (dr-p, agorajek)
- had to disable lag-boamer support due lack of official resource for it
  via disable-lag-baomer.patch
* Mon Jan  4 2021 Adrian Schröter <adrian@suse.de>
- update to version 0.10.4
  * Dropped support for Python 3.5
  * Support for Djibouti (Abdisamade)
  * Support for United Arab Emirates (marcomasulli, mborsetti)
  * Support for Chile (mborsetti, dr-p)
  * Support for Angola (jusce17, pietervdw115, dr-p)
  * Support for Malawi (pietervdw115)
  * Support for Bangladesh (dr-p, tasnimislam)
  * Korea fixes (MYUNGJE, dr-p, hiddentrap)
  * Australia 2020 fix (bencollerson, trauty-is-me)
  * Croatia fixes and updates (jangrg, mborsetti, dr-p)
  * United States fixes (raffg, bgmiles, dr-p)
  * UK fixes/improvements (dr-p, richard-kunert, emreay-)
  * Russia fixes (tserekh)
  * Ireland fixes (chiuczek)
  * Spain observed holidays fix (sermayoral)
  * South Africa observed holidays fix (pietervdw115)
  * France fix (mborsetti)
  * Mexico fix (mborsetti)
  * Singapore 2022 fix (mborsetti)
  * Japan 1990-1993 fixes (sakurai-youhei)
  * Fix on occasional pop_named exception (mborsetti)
  * convertdate fallback if hijri-converter not available (mborsetti, dr-p)
  * enabled Travis tests for python3.9 (mborsetti)
  * added flake8 to unittests (mborsetti)
- disable failing code style test case (adding disable-flake.patch)
* Mon Jul 27 2020 Adrian Schröter <adrian@suse.de>
- Update to version 0.10.3
  Released July 15, 2020
- Added get_named(substring) method to retrieve holidays by name (dr-p)
- Added pop_named(substring) method to pop specific holiday/s by name (samtregar, dr-p)
- Support for Burundi (bmwachajr)
- Support for Latvia (rolandinsh)
- Support for Romania (dorianm)
- Spain fix (dr-p)
- Netherlands fix (RooieRakkert)
- Switzerland fixes (cgrigis)
- Germany fix (MikeTsenatek)
- Added korean_cal attribute to Korea and Vietnam (seriousran, pelennor)
- United States fixes (patrick-nicholson, dr-p)
- Singapore fixes + 2021 holidays (mborsetti)
  Version 0.10.2
  ==============
  Released April 13, 2020
- Support for Spain (piliamaurizio, jbroudou, dr-p, gerardo15)
- Support for Turkey (cemkaragozlu)
- Support for Korea (1kko, dr-p)
- Support for Vietnam (1kko, dr-p)
- Support for Morocco (abensrhir, dr-p)
- Mexico fix (Rosi2143, dr-p)
- Croatia fix (sebojanko, dr-p)
- US Georgia fix (jbroudou, dr-p)
- Austria province ISO3166-2 adoption (jbroudou, dr-p)
- Portugal typos & name fixes (reinaldoramosarxi)
- US MLK renamed (snoopyjc, dr-p)
- ISO-3 codes export fix (dr-p)
* Thu Apr  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.10.1
  * Project structure refactoring (MaxHaertwig, dr-p)
  * Added support for Python3.8 (dr-p)
  * Dropped support for pypy and Python3.4, welcome back pypy3 (dr-p)
  * Fully reviewed Travis CI integration (dr-p)
  * Added 3-digit country ISO codes (MaxHaertwig)
  * Support for Paraguay (dr-p, sfeliu)
  * Support for Israel (giladmaya, dr-p)
  * Support for Egypt (gaberm)
  * Support for Serbia (kosugor)
  * Support for Singapore (mborsetti)
  * README.rst fixes / sync
  * Brazil-Parana support (dr-p, jbroudou)
  * Japan fixes (dr-p, thophan92, saurabh3896)
  * Canada, Spain, US fixes (jbroudou)
  * Belarus fix (mpolyakovsky)
* Fri Jan 17 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 0.9.12:
  * Support for Nigeria (ioluwayo)
  * Support for India - Telangana (kiranbeethoju, dr-p)
  * Support for Dominican Republic (gabmartinez)
  * Support for Nicaragua (CARocha)
  * Code refactoring, bugfixes (vlt)
  * Add method to list all supported countries (fabaff)
  * Germany bugfixes (bitraten)
  * Correctly handle United Kingdom "May Day" holiday in 2020 - #219 (robfraz)
  * Hungary fixes (gypapp)
  * Chile test fixes (rpanai)
  * Italy fixes (jokerigno, sixbladeknife)
  * Other minor fixes
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.11:
  - Added Japanese holidays for new Emperor (kokinamura)
  - Fixed Australian Canberra day holiday (explodingdinosaurs, dr-p)
  - Added support for Estonian holidays (RaulVS14)
  - Added support for Iceland and Kenya (justinasfour04)
  - Added support for Aruba (orson1282)
  - Added support for Hong Kong (polifaces)
  - Added support for Peru (manuelvalino)
  - Switzerland fixes (spasche)
  - Croatia fix (pave121, dr-p)
  - Polish deprecation: replaced by Poland (dr-p)
  - Czech(ia) - Slovak(ia) fixes (dr-p)
  - Allow passing years to CountryHoliday (mr.shu)
* Fri Mar 15 2019 Jan Engelhardt <jengelh@inai.de>
- Remove conjecture from description and ensure neutrality.
* Fri Mar 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.10:
  - Added Lithuanian holidays support (GiedriusMauza)
  - Added Luxembourgish holidays (theFeverDog)
  - Added Russian holidays (mshinkareva)
  - Added Bulgarian holidays (pavelsof)
  - Holidays in date range (elln2)
  - German holidays updates (MrtnBckr, alexanderschulze)
  - South African holidays updates (nickyspag)
  - Australian holidays updates (itssimon)
- Run tests
- Run fdupes
- Fix URL
* Tue Mar 12 2019 Adrian Schröter <adrian@suse.de>
- initial package of version 0.9.9
